Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(23)

Unified Diff: pkg/analysis_server/lib/plugin/completion.dart

Issue 1084793006: Add file missed in previous CL and comment clean-up (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analysis_server/lib/edit/fix/fix_dart.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analysis_server/lib/plugin/completion.dart
diff --git a/pkg/analysis_server/lib/plugin/assist.dart b/pkg/analysis_server/lib/plugin/completion.dart
similarity index 56%
copy from pkg/analysis_server/lib/plugin/assist.dart
copy to pkg/analysis_server/lib/plugin/completion.dart
index cc037f6b087576f8b012c42a6b767dd37be074f3..623fa2b967d23159c9786b3d47958f1a368e5762 100644
--- a/pkg/analysis_server/lib/plugin/assist.dart
+++ b/pkg/analysis_server/lib/plugin/completion.dart
@@ -3,20 +3,20 @@
// BSD-style license that can be found in the LICENSE file.
/**
* Support for client code that extends the analysis server by adding new assist
* contributors.
*/
-library analysis_server.plugin.assist;
+library analysis_server.plugin.completion;
-import 'package:analysis_server/edit/assist/assist_core.dart';
+import 'package:analysis_server/completion/completion_core.dart';
import 'package:analysis_server/src/plugin/server_plugin.dart';
import 'package:analyzer/plugin/plugin.dart';
/**
* The identifier of the extension point that allows plugins to register new
* assist contributors with the server. The object used as an extension must be
* an [AssistContributor].
*/
-final String ASSIST_CONTRIBUTOR_EXTENSION_POINT_ID = Plugin.join(
+final String COMPLETION_CONTRIBUTOR_EXTENSION_POINT_ID = Plugin.join(
ServerPlugin.UNIQUE_IDENTIFIER,
- ServerPlugin.ASSIST_CONTRIBUTOR_EXTENSION_POINT);
+ ServerPlugin.COMPLETION_CONTRIBUTOR_EXTENSION_POINT);
« no previous file with comments | « pkg/analysis_server/lib/edit/fix/fix_dart.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
@@ -3,20 +3,20 @@
// BSD-style license that can be found in the LICENSE file.
/**
- * Support for client code that extends the analysis server by adding new assist
- * contributors.
+ * Support for client code that extends the analysis server by adding new code
+ * completion contributors.
*/
@@ -3,20 +3,20 @@
/**
* The identifier of the extension point that allows plugins to register new
- * assist contributors with the server. The object used as an extension must be
- * an [AssistContributor].
+ * code completion contributors with the server. The object used as an extension
+ * must be a [CompletionContributor].
*/
This is Rietveld 408576698